#!/bin/python3.6

import os

colorDictRGB= {
    "red": "rgb(255,0,0)",
    "blue": "rgb(0,0,255)",
    "green": "rgb(0,255,0)",
    "yellow": "rgb(255,255,0)",
    "orange": "rgb(255,128,0)",
    "purple": "rgb(255,0,255)",
    "black": "rgb(0,0,0)",
    "white": "rgb(255,255,255)",
    "grey": "rgb(128,128,128)"
}

def drawLineList(lineList, width=800, height=800, filePath="lineListDraw.html"):
    """
    Dessine une liste de lignes passe en parametre, dans une zone dessin
    dont les dimension sont donnee en parametre (optionnels) au sein d'un
    fichier html dont le chemin est donne en parametre (optionnel).
    
    :param lineList: liste des lignes a dessiner. Les lignes sont des
        tuples (x1,y1,x2,y2) avec 'x1' et 'y1' les coordonnees (int)(en pixel)
        du point de départ de la ligne, et 'x2' et 'y2' les coordonnees (int)(en pixel)
        du point d'arrivée de la ligne        
    :param width: largeur (int)(en pixel) de la zone de dessin
    :param height: hauteur (int)(en pixel) de la zone de dessin
    
    :param filePath: chaine de caractere representant le chemin, l'emplacement,
        du fichier genere contenant le dessin.
        
    
    :Example:
    
    >>> drawLineList( [ (10,10,100,100), (700,600,650,200) ] )
    >>> drawLineList( [ (200,200,300,500) ], 700, 700, "otherDrawing.html" )
    """

    d= os.path.dirname(filePath)
    script_dir= os.path.dirname(os.path.realpath(__file__))
    if len(d)==0:
        f= open(script_dir+'/'+filePath, 'w')
    else:
        if os.path.isdir(d):
            f= open(filePath, 'w')
        else :
            f= open(script_dir+'/'+filePath, 'w')
    
    f.write("<!DOCTYPE html>\n<html>\n<head><title>TP note - "+filePath+"</title></head>\n")
    f.write("<body>\n<div style=\"overflow-x:auto\">\n<svg width=\""+str(width)+"\" height=\""+str(height)+"\" style=\"border: solid;\">\n")
    
    for line in lineList :
        f.write("<line x1=\""+str(line[0])+"\" y1=\""+str(line[1])+"\" x2=\""+str(line[2])+"\" y2=\""+str(line[3])+"\" style=\"stroke:"+colorDictRGB["black"]+"; stroke-width:2\" />\n")
    
    f.write("</svg>\n</div>\n</body>\n</html>\n")
    
    f.close()


if __name__=="__main__":
    print("Ceci est un module, il ne devrait pas etre execute comme un programme")
